function y=der_sys(u);


% ************************************************
% Le vecteur d'entre u est  11 composantes
%
%	u(1)=p    rotation absolue satellite sur x
%	u(2)=q    ...........................sur y
%	u(3)=r    ...........................sur z
%
%	u(4)=q0   Premire composante du quaternion
%	u(5)=q1   Deuxime ........................
%	u(6)=q2   Troisime .......................
%	u(7)=q3   Quatrime .......................
%
% Les donnes inertielles
%	u(8)=Ir   Inertie roulis
%       u(9)=It   ....... tangage
%	u(10)=Il  ....... lacet
%
% Vitesse angulaire orbitale w0
% 	u(11)     vitesse rotation orbitale
%
% Dans le bloc diagramme nous multiplexerons ces entres
%  7+3+1=11
%
% ******************************************************

p=u(1);q=u(2);r=u(3);
% normalisation du quaternion d'entre
v=u(4:7)/norm(u(4:7));
q0=v(1);q1=v(2);q2=v(3);q3=v(4);
Ir=u(8);It=u(9);Il=u(10);
w0=u(11);

y=[];

% Calcul des drives de p q r

y(1)=(Il-It)/Ir*(-q*r);
y(2)=(Ir-Il)/It*(-p*r);
y(3)=(It-Ir)/Il*(-q*p);

% Calcul des drives du quaternion

p21=2*(q1*q2+q0*q3);
p22=2*(q0^2+q2^2)-1;
p23=2*(q2*q3-q0*q1);

% Matrice W* de rotation relative en temps que quaternion

Matrice_rotation=[0 -p+w0*p21 -q+w0*p22 -r+w0*p23
                 p-w0*p21 0 r-w0*p23 -q+w0*p22
		 q-w0*p22 -r+w0*p23 0 p-w0*p21
		 r-w0*p23 q-w0*p22 -p+w0*p21 0];

z=0.5*Matrice_rotation*[q0 q1 q2 q3]';

y=[y z']';

end
