function [ret,x0,str]=scaoqtn6(t,x,u,flag);
%SCAOQTN6	is the M-file description of the SIMULINK system named SCAOQTN6.
%	The block-diagram can be displayed by typing: SCAOQTN6.
%
%	SYS=SCAOQTN6(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAOQTN6 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAOQTN6 with a FLAG of zero:
%	[SIZES]=SCAOQTN6([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[30,97,584,446])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'RK-45')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'30')
set_param(sys,'Min step size',	'0.002')
set_param(sys,'Max step size',	'0.002')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/Note',[sys,'/',['QUATERNIONS:',13,'ETUDE DU MOUVEMENT DE LAGRANGE ET POISSON']])
set_param([sys,'/',['QUATERNIONS:',13,'ETUDE DU MOUVEMENT DE LAGRANGE ET POISSON']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[280,5,281,6])


%     Subsystem  'XY Graph1'.

new_system([sys,'/','XY Graph1'])
set_param([sys,'/','XY Graph1'],'Location',[0,0,274,193])

add_block('built-in/Inport',[sys,'/','XY Graph1/y'])
set_param([sys,'/','XY Graph1/y'],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/','XY Graph1/x'])
set_param([sys,'/','XY Graph1/x'],...
		'position',[10,30,30,50])

add_block('built-in/Mux',[sys,'/','XY Graph1/Mux'])
set_param([sys,'/','XY Graph1/Mux'],...
		'inputs','2',...
		'position',[100,61,130,94])

add_block('built-in/S-function',[sys,'/',['XY Graph1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['XY Graph1/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunxy',...
		'parameters','ax',...
		'position',[185,70,235,90])
add_line([sys,'/','XY Graph1'],[35,110;70,110;70,85;90,85])
add_line([sys,'/','XY Graph1'],[35,40;70,40;70,70;90,70])
add_line([sys,'/','XY Graph1'],[135,80;175,80])
set_param([sys,'/','XY Graph1'],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[51,57,65,75,80,79,75,67,60,54,51,48,42,34,28,27,31,42,51],[71,68,66,66,72,79,83,84,81,77,71,60,54,54,58,65,71,74,71])')
set_param([sys,'/','XY Graph1'],...
		'Mask Type','XY scope.',...
		'Mask Dialogue','XY scope using MATLAB graph window.\nFirst input is used as time base.\nEnter plotting ranges.|x-min|x-max|y-min|y-max')
set_param([sys,'/','XY Graph1'],...
		'Mask Translate','ax = [@1, @2, @3, @4];',...
		'Mask Help','This block can be used to explore limit cycles. Look at the m-file sfunxy.m to see how it works.',...
		'Mask Entries','-1\/1\/-1\/1\/')


%     Finished composite block 'XY Graph1'.

set_param([sys,'/','XY Graph1'],...
		'BackGround',3,...
		'Drop Shadow',4,...
		'position',[460,128,500,192])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','2*(u(5)*u(7)+u(4)*u(6))',...
		'Output Width','1',...
		'position',[365,130,415,160])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','2*(u(6)*u(7)-u(4)*u(5))',...
		'Output Width','1',...
		'position',[365,160,415,190])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'MATLAB Fcn','-2*(u(6)*u(7)+u(4)*u(5))',...
		'Output Width','1',...
		'position',[245,205,295,235])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'inputs','3',...
		'position',[95,196,120,334])

add_block('built-in/Note',[sys,'/',['Calcul couple',13,'pesanteur']])
set_param([sys,'/',['Calcul couple',13,'pesanteur']],...
		'ForeGround',4,...
		'Font Size',14,...
		'position',[185,225,186,226])

add_block('built-in/Constant',[sys,'/','Constant1'])
set_param([sys,'/','Constant1'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Value','0',...
		'position',[245,295,290,325])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[133,155,619,460])
open_system([sys,'/','UnNamed'])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'orientation',2,...
		'MATLAB Fcn','lagrange(u)',...
		'Output Width','7',...
		'position',[95,190,145,220])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 2]',...
		'position',[180,134,210,276])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/A 0 0;0 1/A 0;0 0 1/C;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/Integrator'])
set_param([sys,'/','UnNamed/Integrator'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[A C]',...
		'position',[240,227,320,253])
add_line([sys,'/','UnNamed'],[160,65;250,65])
add_line([sys,'/','UnNamed'],[90,205;70,205;70,110;250,110])
add_line([sys,'/','UnNamed'],[175,205;155,205])
add_line([sys,'/','UnNamed'],[235,240;220,240])
add_line([sys,'/','UnNamed'],[350,90;405,90])
add_line([sys,'/','UnNamed'],[360,90;360,170;220,170])
add_line([sys,'/','UnNamed'],[280,90;300,90])
add_line([sys,'/','UnNamed'],[50,65;90,65])
set_param([sys,'/','UnNamed'],...
		'Mask Display','DYNAMIQUE\n\nSATELLITE\n\nQUATERNIONS')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[150,109,280,181])

add_block('built-in/Note',[sys,'/',['SORTIE DE LA TRAJECTOIRE',13,'DE L''EXTREMITE DE L''AXE  ',13,'z SUR LE PLAN XOY']])
set_param([sys,'/',['SORTIE DE LA TRAJECTOIRE',13,'DE L''EXTREMITE DE L''AXE  ',13,'z SUR LE PLAN XOY']],...
		'ForeGround',3,...
		'Font Size',12,...
		'position',[435,215,436,216])

add_block('built-in/Note',[sys,'/','Sign: GUIZIOU 1995'])
set_param([sys,'/','Sign: GUIZIOU 1995'],...
		'position',[490,330,491,331])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Gain','Mgd',...
		'position',[70,127,105,163])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'MATLAB Fcn','2*(u(5)*u(7)-u(4)*u(6))',...
		'Output Width','1',...
		'position',[245,250,295,280])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn4'])
set_param([sys,'/','MATLAB Fcn4'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','det(quatpass(u))',...
		'Output Width','1',...
		'position',[380,275,430,305])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','det',...
		'position',[460,282,510,298])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','x',...
		'position',[455,52,505,68])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'hide name',0,...
		'mat-name','y',...
		'position',[455,92,505,108])
add_line(sys,[285,145;355,145])
add_line(sys,[420,145;450,145])
add_line(sys,[420,175;450,175])
add_line(sys,[330,145;330,175;355,175])
add_line(sys,[330,175;330,220;305,220])
add_line(sys,[240,220;130,220])
add_line(sys,[240,310;130,310])
add_line(sys,[240,265;130,265])
add_line(sys,[110,145;140,145])
add_line(sys,[90,265;20,265;20,145;60,145])
add_line(sys,[330,220;330,265;305,265])
add_line(sys,[430,175;430,100;445,100])
add_line(sys,[330,265;331,290;370,290])
add_line(sys,[435,290;450,290])
add_line(sys,[420,145;420,60;445,60])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
