function [ret,x0,str]=scaoqtn1(t,x,u,flag);
%SCAOQTN1	is the M-file description of the SIMULINK system named SCAOQTN1.
%	The block-diagram can be displayed by typing: SCAOQTN1.
%
%	SYS=SCAOQTN1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAOQTN1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAOQTN1 with a FLAG of zero:
%	[SIZES]=SCAOQTN1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[15,71,612,398])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'RK-45')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'10000')
set_param(sys,'Min step size',	'20')
set_param(sys,'Max step size',	'20')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/Note',[sys,'/','Gradient de gravit'])
set_param([sys,'/','Gradient de gravit'],...
		'ForeGround',5,...
		'position',[275,45,276,46])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','0.020000',...
		'Hgain','10000.000000',...
		'Vmax','0.040000',...
		'Hmax','20000.000000',...
		'Window',[2,88,324,468])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[460,150,490,180])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','20.000000',...
		'Hgain','10000.000000',...
		'Vmax','40.000000',...
		'Hmax','20000.000000',...
		'Window',[305,89,627,469])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[460,70,490,100])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','-180/pi*asin(2*(u(5)*u(7)-u(4)*u(6)))',...
		'Output Width','1',...
		'position',[285,88,345,122])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','180/pi*(u(2)-rotation_orbitale)',...
		'Output Width','1',...
		'position',[285,133,345,167])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',5,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','1500',...
		'position',[165,177,215,193])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'hide name',0,...
		'position',[110,175,130,195])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','1500',...
		'position',[395,142,445,158])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','1500',...
		'position',[395,97,445,113])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[133,155,619,460])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'orientation',2,...
		'MATLAB Fcn','der_sys(u)',...
		'Output Width','7',...
		'position',[95,190,145,220])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'orientation',2,...
		'inputs','[7 3 1]',...
		'position',[180,134,210,276])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant'])
set_param([sys,'/','UnNamed/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[235,192,315,218])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant1'])
set_param([sys,'/','UnNamed/Constant1'],...
		'orientation',2,...
		'Value','rotation_orbitale',...
		'position',[235,237,315,263])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/State-space',[sys,'/','UnNamed/Matrix gain.'])
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Integrator',[sys,'/','UnNamed/Integrator'])
set_param([sys,'/','UnNamed/Integrator'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])
add_line([sys,'/','UnNamed'],[160,65;250,65])
add_line([sys,'/','UnNamed'],[90,205;70,205;70,110;250,110])
add_line([sys,'/','UnNamed'],[175,205;155,205])
add_line([sys,'/','UnNamed'],[230,250;220,250])
add_line([sys,'/','UnNamed'],[230,205;220,205])
add_line([sys,'/','UnNamed'],[350,90;405,90])
add_line([sys,'/','UnNamed'],[360,90;360,160;220,160])
add_line([sys,'/','UnNamed'],[280,90;300,90])
add_line([sys,'/','UnNamed'],[50,65;90,65])
set_param([sys,'/','UnNamed'],...
		'Mask Display','DYNAMIQUE\n\nSATELLITE\n\nQUATERNIONS',...
		'Mask Type','',...
		'Mask Dialogue','GRADIENT DE GRAVITE|Ir roulis (kg-m)|It tangage (kg-m)|Il lacet (kg-m)')
set_param([sys,'/','UnNamed'],...
		'Mask Translate','global Ir It Il etat_init rotation_orbitale;Ir=@1;It=@2;Il=@3',...
		'Mask Help','',...
		'Mask Entries','135\/135\/7\/')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[120,69,250,141])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Value','[0 0 0]''',...
		'position',[20,91,80,119])

add_block('built-in/Note',[sys,'/','QUATERNIONS:ETUDE DU TANGAGE SEUL'])
set_param([sys,'/','QUATERNIONS:ETUDE DU TANGAGE SEUL'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[290,10,291,11])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,118,108,334])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\nSIMULATION SCAOQTN1\npar double clic souris',...
		'Mask Type','',...
		'Mask Dialogue','eval(''scaodat1'')',...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[355,210,495,255])

add_block('built-in/Note',[sys,'/','Sign: GUIZIOU janvier 1995'])
set_param([sys,'/','Sign: GUIZIOU janvier 1995'],...
		'position',[85,260,86,261])
add_line(sys,[85,105;110,105])
add_line(sys,[135,185;155,185])
add_line(sys,[255,105;275,105])
add_line(sys,[350,105;385,105])
add_line(sys,[350,105;350,85;450,85])
add_line(sys,[350,150;385,150])
add_line(sys,[350,150;350,165;450,165])
add_line(sys,[255,105;255,150;275,150])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
